==> qt5-5.0.0-3-i686.pkg.tar.xz: usr/lib/cmake/Qt5QuickTest/Qt5QuickTestConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5QuickTest_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

set(Qt5QuickTest_VERSION_MAJOR 5)
set(Qt5QuickTest_VERSION_MINOR 0)
set(Qt5QuickTest_VERSION_PATCH 0)
set(Qt5QuickTest_VERSION_STRING 5.0.0)

set(Qt5QuickTest_LIBRARIES Qt5::QuickTest)

set(Qt5QuickTest_INCLUDE_DIRS "${_qt5QuickTest_install_prefix}/include/qt5/" "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest")
set(Qt5QuickTest_PRIVATE_INCLUDE_DIRS
    "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest/${Qt5QuickTest_VERSION_STRING}"
    "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest/${Qt5QuickTest_VERSION_STRING}/QtQuickTest"
)

set(Qt5QuickTest_DEFINITIONS -DQT_QMLTEST_LIB)
set(Qt5QuickTest_COMPILE_DEFINITIONS QT_QMLTEST_LIB)

set(_Qt5QuickTest_MODULE_DEPENDENCIES "Core")

set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED)
if (Qt5QuickTest_FIND_REQUIRED)
    set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED REQUIRED)
endif()
set(_Qt5QuickTest_FIND_DEPENDENCIES_QUIET)
if (Qt5QuickTest_FIND_QUIETLY)
    set(_Qt5QuickTest_DEPENDENCIES_FIND_QUIET QUIET)
endif()

foreach(_module_dep ${_Qt5QuickTest_MODULE_DEPENDENCIES})
    if (NOT Qt5${_module_dep}_FOUND)
        find_package(Qt5${_module_dep}
            ${_Qt5QuickTest_DEPENDENCIES_FIND_QUIET}
            ${_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED}
            PATHS "${_qt5QuickTest_install_prefix}" NO_DEFAULT_PATH
        )
    endif()

    if (NOT Qt5${_module_dep}_FOUND)
        set(Qt5QuickTest_FOUND False)
        return()
    endif()

    list(APPEND Qt5QuickTest_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
    list(APPEND Qt5QuickTest_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
    list(APPEND Qt5QuickTest_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
    list(APPEND Qt5QuickTest_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
    list(APPEND Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
endforeach()
list(REMOVE_DUPLICATES Qt5QuickTest_INCLUDE_DIRS)
list(REMOVE_DUPLICATES Qt5QuickTest_PRIVATE_INCLUDE_DIRS)
list(REMOVE_DUPLICATES Qt5QuickTest_DEFINITIONS)
list(REMOVE_DUPLICATES Qt5QuickTest_COMPILE_DEFINITIONS)
if (Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS)
  list(REMOVE_DUPLICATES Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS)
endif()

set(_Qt5QuickTest_LIB_DEPENDENCIES "Qt5::Core")

macro(_populate_imported_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::QuickTest APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::QuickTest PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5QuickTest_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "${_qt5QuickTest_install_prefix}/lib/${LIB_LOCATION}"
        "IMPORTED_SONAME_${Configuration}" "libQt5QuickTest.so.5"
    )
endmacro()

if (NOT TARGET Qt5::QuickTest)
    add_library(Qt5::QuickTest SHARED IMPORTED)


    _populate_imported_target_properties(RELEASE "libQt5QuickTest.so.5.0.0" "" )



endif()

==> qt5-5.0.1-3-i686.pkg.tar.xz: usr/lib/cmake/Qt5QuickTest/Qt5QuickTestConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5QuickTest_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

set(Qt5QuickTest_VERSION_MAJOR 5)
set(Qt5QuickTest_VERSION_MINOR 0)
set(Qt5QuickTest_VERSION_PATCH 1)
set(Qt5QuickTest_VERSION_STRING 5.0.1)

set(Qt5QuickTest_LIBRARIES Qt5::QuickTest)

set(Qt5QuickTest_INCLUDE_DIRS "${_qt5QuickTest_install_prefix}/include/qt5/" "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest")
set(Qt5QuickTest_PRIVATE_INCLUDE_DIRS
    "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest/${Qt5QuickTest_VERSION_STRING}"
    "${_qt5QuickTest_install_prefix}/include/qt5/QtQuickTest/${Qt5QuickTest_VERSION_STRING}/QtQuickTest"
)

set(Qt5QuickTest_DEFINITIONS -DQT_QMLTEST_LIB)
set(Qt5QuickTest_COMPILE_DEFINITIONS QT_QMLTEST_LIB)

set(_Qt5QuickTest_MODULE_DEPENDENCIES "Widgets;Core")

set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED)
if (Qt5QuickTest_FIND_REQUIRED)
    set(_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED REQUIRED)
endif()
set(_Qt5QuickTest_FIND_DEPENDENCIES_QUIET)
if (Qt5QuickTest_FIND_QUIETLY)
    set(_Qt5QuickTest_DEPENDENCIES_FIND_QUIET QUIET)
endif()

foreach(_module_dep ${_Qt5QuickTest_MODULE_DEPENDENCIES})
    if (NOT Qt5${_module_dep}_FOUND)
        find_package(Qt5${_module_dep}
            ${_Qt5QuickTest_DEPENDENCIES_FIND_QUIET}
            ${_Qt5QuickTest_FIND_DEPENDENCIES_REQUIRED}
            PATHS "${_qt5QuickTest_install_prefix}" NO_DEFAULT_PATH
        )
    endif()

    if (NOT Qt5${_module_dep}_FOUND)
        set(Qt5QuickTest_FOUND False)
        return()
    endif()

    list(APPEND Qt5QuickTest_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
    list(APPEND Qt5QuickTest_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
    list(APPEND Qt5QuickTest_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
    list(APPEND Qt5QuickTest_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
    list(APPEND Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
endforeach()
list(REMOVE_DUPLICATES Qt5QuickTest_INCLUDE_DIRS)
list(REMOVE_DUPLICATES Qt5QuickTest_PRIVATE_INCLUDE_DIRS)
list(REMOVE_DUPLICATES Qt5QuickTest_DEFINITIONS)
list(REMOVE_DUPLICATES Qt5QuickTest_COMPILE_DEFINITIONS)
if (Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS)
  list(REMOVE_DUPLICATES Qt5QuickTest_EXECUTABLE_COMPILE_FLAGS)
endif()

set(_Qt5QuickTest_LIB_DEPENDENCIES "Qt5::Widgets;Qt5::Core")

macro(_populate_imported_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::QuickTest APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::QuickTest PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5QuickTest_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "${_qt5QuickTest_install_prefix}/lib/${LIB_LOCATION}"
        "IMPORTED_SONAME_${Configuration}" "libQt5QuickTest.so.5"
    )
endmacro()

if (NOT TARGET Qt5::QuickTest)
    add_library(Qt5::QuickTest SHARED IMPORTED)


    _populate_imported_target_properties(RELEASE "libQt5QuickTest.so.5.0.1" "" )



endif()
